@@ -9,6 +9,7 @@ from .jira import Jira
 from .marketplace import MarketPlace
 from .portfolio import Portfolio
 from .service_desk import ServiceDesk
+from .service_desk import ServiceDesk as ServiceManagement
 from .xray import Xray
 
 
@@ -23,6 +24,7 @@ __all__ = [
     "Stash",
     "Crowd",
     "ServiceDesk",
+    "ServiceManagement",
     "MarketPlace",
     "Xray",
     "Insight",
